# -*- coding: utf-8 -*-
"""Recipe links"""

import os
import re
import glob
import logging

class Recipe(object):
    """zc.buildout recipe"""

    def __init__(self, buildout, name, options):
        self.buildout, self.name, self.options = buildout, name, options
        self.regexp = options.get('regexp', '.*')
        self.logger = logging.getLogger(name)
        self.symlink_target = os.path.join(self.buildout['buildout']['directory'],
                               self.options.get('symlink-target'))
        self.eggs = options.get('targets', '').splitlines()

    def install(self):
        """Installer"""
        # XXX Implement recipe functionality here
        
        # Return files that were created by the recipe. The buildout
        # will remove all returned files upon reinstall.

        ignored = self.options.get('ignore')
        autocreate = self.options.get('autocreate')
        if self.symlink_target:
            self.symlink_target = os.path.expanduser(self.symlink_target)
            if not os.path.isdir(self.symlink_target):
               self.logger.debug("Target dir %s does not exist." % self.symlink_target)
               if autocreate:
                  os.makedirs(self.symlink_target)
               else:
                  raise RuntimeError("Target directory %s does not exist." % self.symlink_target)

            # target is specified, so there might be bulk items

            pth = glob.glob('parts/*/*/*/*/virtual-python.pth')[0]
            items = [f for f in open(pth).read().splitlines() if os.path.isdir(f)]

            egg_dirs = {}
            for egg in items:
                try:
                    pkg_name = self.get_pkg_name(egg)
                except IndexError: # when glob fails
                    continue
                if pkg_name in self.eggs:
                    egg_dirs[pkg_name] = egg

        for target, source in egg_dirs.iteritems():
            target = os.path.join(self.symlink_target, target)
            if os.path.exists(target):
                self.logger.debug('Symlink target %s already exists' % target)
                if os.path.exists(target):
                    os.unlink(target)
            else:
                os.symlink(source, target)
                self.logger.debug("creating link for %s at %s" % (source, target))
            
#        import ipdb; ipdb.set_trace()
        return (self.symlink_target,)

    def get_pkg_name(self, egg):

        info_dir = os.path.join(egg, 'EGG-INFO')
        if not os.path.exists(info_dir):
            info_dir = glob.glob("%s/*egg-info" % (egg))[0]

        PKG_INFO = open(os.path.join(info_dir, 'PKG-INFO')).read()
        pkg_name = [line.split(': ')[1] for line in PKG_INFO.splitlines()
                    if line.startswith('Name')][0]
        return pkg_name
        
    def update(self):
        """Updater"""
        self.install()
    
